@@ -32,6 +32,9 @@ from suite_py.lib.tokens import Tokens
 
 from suite_py.lib import logger
 
+ALLOW_NO_GIT_SUBCOMMAND = ["login", "qa", "aggregator"]
+ALLOW_NO_HOME_SUBCOMMAND = ["login", "qa", "aggregator"]
+
 
 @click.group()
 @click.option(
@@ -53,11 +56,15 @@ def main(ctx, project, timeout, verbose):
 
     config = Config()
 
-    if not git.is_repo(project):
+    if ctx.invoked_subcommand not in ALLOW_NO_GIT_SUBCOMMAND and not git.is_repo(
+        project
+    ):
         print(f"the folder {project} is not a git repo")
         sys.exit(-1)
 
-    if not os.path.basename(project) in os.listdir(config.user["projects_home"]):
+    if ctx.invoked_subcommand not in ALLOW_NO_HOME_SUBCOMMAND and not os.path.basename(
+        project
+    ) in os.listdir(config.user["projects_home"]):
         print(f"the folder {project} is not in {config.user['projects_home']}")
         sys.exit(-1)
 
@@ -76,7 +83,13 @@ def main(ctx, project, timeout, verbose):
         config.user["captainhook_timeout"] = timeout
     ctx.obj["config"] = config
     ctx.obj["tokens"] = Tokens()
-    os.chdir(os.path.join(config.user["projects_home"], ctx.obj["project"]))
+
+    # Skip chdir if not needed
+    if (
+        ctx.invoked_subcommand not in ALLOW_NO_GIT_SUBCOMMAND
+        or ctx.invoked_subcommand not in ALLOW_NO_HOME_SUBCOMMAND
+    ):
+        os.chdir(os.path.join(config.user["projects_home"], ctx.obj["project"]))
 
 
 @main.command(
