@@ -222,7 +222,7 @@ class QA:
         )
 
         qa_card = prompt_utils.ask_questions_input(
-            "Youtrack issue ID: ", default_text=""
+            "Youtrack issue ID: ", default_text="PRIMA-xxxx"
         )
 
         srv_list = self._qainit.create_services_body(prj_list=self._flags)
